==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/TransitionDirection.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TransitionDirection.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="TransitionDirection"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="leftToRight"/&gt;
 *     &lt;enumeration value="bottomToTop"/&gt;
 *     &lt;enumeration value="rightToLeft"/&gt;
 *     &lt;enumeration value="topToBottom"/&gt;
 *     &lt;enumeration value="topLeftToBottomRight"/&gt;
 *     &lt;enumeration value="none"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "TransitionDirection")
@XmlEnum
public enum TransitionDirection {

    @XmlEnumValue("leftToRight")
    LEFT_TO_RIGHT("leftToRight"),
    @XmlEnumValue("bottomToTop")
    BOTTOM_TO_TOP("bottomToTop"),
    @XmlEnumValue("rightToLeft")
    RIGHT_TO_LEFT("rightToLeft"),
    @XmlEnumValue("topToBottom")
    TOP_TO_BOTTOM("topToBottom"),
    @XmlEnumValue("topLeftToBottomRight")
    TOP_LEFT_TO_BOTTOM_RIGHT("topLeftToBottomRight"),
    @XmlEnumValue("none")
    NONE("none");
    private final String value;

    TransitionDirection(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static TransitionDirection fromValue(String v) {
        for (TransitionDirection c: TransitionDirection.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/TransitionDirection.java <==

package net.webpdf.wsclient.schema.extraction.info;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TransitionDirection.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>{@code
 * <simpleType name="TransitionDirection">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="leftToRight"/>
 *     <enumeration value="bottomToTop"/>
 *     <enumeration value="rightToLeft"/>
 *     <enumeration value="topToBottom"/>
 *     <enumeration value="topLeftToBottomRight"/>
 *     <enumeration value="none"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "TransitionDirection")
@XmlEnum
public enum TransitionDirection {

    @XmlEnumValue("leftToRight")
    LEFT_TO_RIGHT("leftToRight"),
    @XmlEnumValue("bottomToTop")
    BOTTOM_TO_TOP("bottomToTop"),
    @XmlEnumValue("rightToLeft")
    RIGHT_TO_LEFT("rightToLeft"),
    @XmlEnumValue("topToBottom")
    TOP_TO_BOTTOM("topToBottom"),
    @XmlEnumValue("topLeftToBottomRight")
    TOP_LEFT_TO_BOTTOM_RIGHT("topLeftToBottomRight"),
    @XmlEnumValue("none")
    NONE("none");
    private final String value;

    TransitionDirection(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static TransitionDirection fromValue(String v) {
        for (TransitionDirection c: TransitionDirection.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
